
# Type: owner


the "owner" of the slot. It is the class if it appears in the slots list, otherwise the declaring slot

URI: [meta:owner](https://w3id.org/biolink/biolinkml/meta/owner)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Definition](Definition.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
